import acm.program.*;
import acm.util.*;
import java.io.*;
import java.net.*;

public class WebReader extends ConsoleProgram {
	public void run() {	
		while (true) {
			String query = readLine("Enter a query: ");
			println(getNumResults(query));
		}
	}
	
	/**
	 * Does a Google search and reports how many results were
	 * found.
	 * 
	 * @param query The query to execute.
	 * @return The number of search results.
	 */
	private String getNumResults(String query) {
		/* Do a Google search. */
		String googleText = doGoogleSearch(query);
		if (googleText == null) {
			return "Something went wrong.";
		}
		
		/* The text format is About NNN results, so we want to
		 * look for "About " and "results."
		 */
		int aboutIndex = googleText.indexOf("About ");
		if (aboutIndex == -1) {
			return "Google doesn't like us.";
		}
		
		int resultIndex = googleText.indexOf("results", aboutIndex);
		if (resultIndex == -1) {
			return "Google still doesn't like us.";
		}
		
		return googleText.substring(aboutIndex, resultIndex);
	}
	
	/**
	 * Performs the specified search query on Google, returning
	 * the text of the response page.
	 * 
	 * @param query The query to perform.
	 * @return The full text of the response page.
	 */
	private String doGoogleSearch(String query) {
		/* Google queries, at the HTTP level, can't have spaces
		 * in them.  Replace all spaces with the + character.
		 */
		query = query.replace(' ', '+');
		try {
			/* Open a connection to Google. */
			Socket s = new Socket("www.google.com", 80);
			
			/* Create an HTTP request to do a search for the given
			 * query, then send it.
			 */
			PrintWriter pw = new PrintWriter(s.getOutputStream());
			pw.println("GET /search?q=" + query + " HTTP/1.0");
			pw.println("User-Agent: CS106A!");
			pw.println();
			pw.println();
			pw.flush();
			
			/* Read the response and reconstruct it one line at a time. */
			BufferedReader br = new BufferedReader(new InputStreamReader(s.getInputStream()));
			String result = "";
			
			while (true) {
				String line = br.readLine();
				if (line == null) break;
				
				result += line + '\n';
			}
			
			s.close();
			return result;
			
		} catch (IOException e) {
			return null;
		}
	}
}
